@@ -8,8 +8,11 @@ parser_name = "rst"
 writer_name = "latex"
 
 # Extra setting we need
-settings_overrides['literal_block_env'] = 'lstlisting'
+settings_overrides['legacy_class_functions'] = False
+settings_overrides['stylesheet'] = 'docutils'
 settings_overrides['syntax_highlight'] = 'none'
+
+settings_overrides['literal_block_env'] = 'lstlisting'
 settings_overrides['latex_preamble'] = r"""
 % PDF Standard Fonts
 \usepackage{mathptmx} % Times
